# Developer Notes

Scratch junk, please ignore




# Licensing

All packages used in Uvicore are permissive and compatible with the MIT license.

**Direct Dependencies***
* python - PSF License, BSD-style, copyright and permissive, safe with MIT
* fastapi - MIT
* uvicorn - BSD 3-Clause
* gunicorn - MIT
* aiofiles - Apache License 2.0
* databases - BSD 3-Clause
* alembic - MIT
* asyncclick - BSD 3-Clause
* colored - MIT
* prettyprinter - MIT
* environs - MIT
* jinja2 - BSD 3-Clause
* ipython - BSD 3-Clause
* requests - Apache License 2.0


**Indirect Subdependencies***
* sqlalchemy - MIT
* click - BSD 3-Clause
* aiomysql - MIT



**From pip-licenses output**

* cardet is LGPL not GPL, so we are safe to link to the library
* text-unicode is a 3 license, which means I get to pick whichever license I want to impose, I choose Artistic License since it is permissive.
* The ISC License is permissive, so good there
* The MPL 2.0 is permissive and not viral, should be good here.

```
 Name              Version    License
 Faker             4.18.0     MIT License
 Jinja2            2.11.2     BSD License
 Mako              1.1.4      MIT License
 MarkupSafe        1.1.1      BSD License
 PyMySQL           0.9.2      MIT License
 Pygments          2.7.4      BSD License
 SQLAlchemy        1.3.22     MIT License
 aiofiles          0.6.0      Apache Software License
 aiomysql          0.0.20     MIT License
 alembic           1.5.2      MIT License
 anyio             2.0.2      MIT License
 asgiref           3.3.1      BSD License
 asyncclick        7.1.2.3    BSD License
 backcall          0.2.0      BSD License
 certifi           2020.12.5  Mozilla Public License 2.0 (MPL 2.0)
 cffi              1.14.4     MIT License
 chardet           4.0.0      GNU Library or Lesser General Public License (LGPL)
 click             7.1.2      BSD License
 colored           1.4.2      MIT License
 colorful          0.5.4      MIT License
 cryptography      3.3.1      Apache Software License, BSD License
 databases         0.4.1      BSD License
 decorator         4.4.2      BSD License
 environs          9.3.0      MIT License
 fastapi           0.63.0     MIT License
 gunicorn          20.0.4     MIT License
 h11               0.12.0     MIT License
 idna              2.10       BSD License
 ipython           7.19.0     BSD License
 ipython-genutils  0.2.0      BSD License
 jedi              0.18.0     MIT License
 marshmallow       3.10.0     MIT License
 parso             0.8.1      MIT License
 pexpect           4.8.0      ISC License (ISCL)
 pickleshare       0.7.5      MIT License
 prettyprinter     0.18.0     MIT License
 prompt-toolkit    3.0.14     BSD License
 ptyprocess        0.7.0      ISC License (ISCL)
 pycparser         2.20       BSD License
 pydantic          1.7.3      MIT License
 python-dateutil   2.8.1      BSD License, Apache Software License
 python-dotenv     0.15.0     BSD License
 python-editor     1.0.4      Apache Software License
 requests          2.25.1     Apache Software License
 six               1.15.0     MIT License
 sniffio           1.2.0      MIT License, Apache Software License
 starlette         0.13.6     BSD License
 text-unidecode    1.3        Artistic License, GNU General Public License (GPL), GNU General Public License v2 or later (GPLv2+)
 traitlets         5.0.5      BSD License
 urllib3           1.26.3     MIT License
 uvicore           0.1.5      MIT License
 uvicorn           0.13.3     BSD License
 wcwidth           0.2.5      MIT License
 ```
